Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(83)

Unified Diff: chrome/browser/ui/extensions/shell_window.h

Issue 17378003: [WIN]Save work area of window and adjust bounds to ensure it fit on screen before show. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/extensions/shell_window.h
diff --git a/chrome/browser/ui/extensions/shell_window.h b/chrome/browser/ui/extensions/shell_window.h
index 64e66c744c33d8e6024e7c70500d4bb29226bead..3f2f6593a25ea3b65bf69c8704d62ae9522904d9 100644
--- a/chrome/browser/ui/extensions/shell_window.h
+++ b/chrome/browser/ui/extensions/shell_window.h
@@ -260,9 +260,16 @@ class ShellWindow : public content::NotificationObserver,
void AddMessageToDevToolsConsole(content::ConsoleMessageLevel level,
const std::string& message);
// Saves the window geometry/position.
void SaveWindowPosition();
+ // Helper method to adjust the cached bounds so that we can make sure it can
+ // be visible on the screen. See http://crbug.com/145752 .
+ void AdjustBoundsToBeVisibleOnMonitorContaining(
+ const gfx::Rect& cached_bounds,
+ const gfx::Rect& cached_work_area,
+ gfx::Rect* bounds) const;
+
// Load the app's image, firing a load state change when loaded.
void UpdateExtensionAppIcon();
@@ -260,9 +260,16 @@ class ShellWindow : public content::NotificationObserver,
void AddMessageToDevToolsConsole(content::ConsoleMessageLevel level,
const std::string& message);
- // Saves the window geometry/position.
+ // Saves the window geometry/position/work_area.
void SaveWindowPosition();

Powered by Google App Engine
This is Rietveld 408576698